'use strict'

const argx = require('argx')
const co = require('co')
const apemancwd = require('apemancwd')
const arrayreduce = require('arrayreduce')
const arrayfilter = require('arrayfilter')
const apemanfile = require('apemanfile')
const cipherjson = require('cipherjson')
const askPassword = require('./asking/ask_password')
const readlineSync = require('readline-sync')
const updateSecret = require('./secret/update_secret')

let concatArray = arrayreduce.arrayConcat()
let rejectEmpty = arrayfilter.emptyReject()

/** @lends apemanScrt */
function apemanScrt (names, options) {
  let args = argx(arguments)
  options = args.pop('object') || {}
  names = args.remain().filter(rejectEmpty).reduce(concatArray, [])

  let cwd = apemancwd.create({ prefix: 'apeman-scrt' })

  return co(function * () {
    let configuration = apemanfile(options.configuration)
    cwd.chdir(configuration.$cwd)
    let filename = configuration.$scrt || './secret.json'

    let password = yield askPassword(options.password)
    let cipher = cipherjson(password)
    yield updateSecret(cipher, filename, {
      keys: names
    })
    cwd.restoreAll()
  })
}

apemanScrt.expose = function (filename, password) {
  if (!password) {
    password = readlineSync.question('password: ')
  }
  return cipherjson(password).readSync(filename)
}

module.exports = apemanScrt
