/**
 * @function updateSecret
 * @returns {Promise}
 */

'use strict'

const co = require('co')
const askconfig = require('askconfig')
const UpdateLogger = require('../logging/update_logger')

/** @lends updateSecret */
function updateSecret (cipher, filename, options = {}) {
  let keys = [].concat(options.keys || [])

  let logger = new UpdateLogger({})
  return co(function * () {
    let data = yield cipher.read(filename)
    let asking = {}
    Object.keys(data)
      .concat(keys)
      .filter((key) => {
        let hasKeys = keys.length > 0
        if (hasKeys) {
          return keys.indexOf(key) !== -1
        }
        return true
      })
      .forEach((key) => {
        asking[ key ] = data[ key ] || ''
      })
    let asked = yield askconfig(asking)
    let result = yield cipher.write(filename, asked)
    logger.logSecretUpdated(result.filename)
  })
}

module.exports = updateSecret
